hvl\_ccb.dev.tiepie.device
==========================

**NOTE**: `libtiepie`_ tries to load the `libtiepie SDK`_ during import.
Thus, the API docs can only be generated in a system with the
latter installed.

.. _`libtiepie`: https://pypi.org/project/python-libtiepie/
.. _`libtiepie SDK`: https://www.tiepie.com/en/libtiepie-sdk

To build the API docs for this subpackage locally edit all files that match
:code:`docs/hvl_ccb.dev.tiepie.XXX.rst` and remove the :code:`.. code-block::`
directive preceding the following directives:

.. code-block::

    .. inheritance-diagram:: hvl_ccb.dev.tiepie.device
       :parts: 1


    .. automodule:: hvl_ccb.dev.tiepie.device
       :members:
       :undoc-members:
       :show-inheritance:
